#include "CurveEvaluators.h"

#include <assert.h>

#include "CurveEvaluator.h"

#ifndef WIN32
CurveEvaluators *CurveEvaluators::m_instance=NULL;
#endif

CurveEvaluators::~CurveEvaluators(void)
{
	cleanupCurveEvaluators();
}

void CurveEvaluators::addCurveEvaluator(const std::string & curve_name, CurveEvaluator * curve_evaluator)
{
	m_curve_name_evaluator_mapping.insert(CurveNameEvaluatorMapping::value_type(curve_name, curve_evaluator));
}

CurveEvaluator * CurveEvaluators::getCurveEvaluator(const std::string & curve_name) const
{
	CurveNameEvaluatorMapping::const_iterator find_result = m_curve_name_evaluator_mapping.find(curve_name);

	bool found = (find_result != m_curve_name_evaluator_mapping.end());

	assert(found);

	return find_result->second;
}

CurveEvaluators::const_iterator CurveEvaluators::begin(void) const
{
	return m_curve_name_evaluator_mapping.begin();
}

CurveEvaluators::const_iterator CurveEvaluators::end(void) const
{
	return m_curve_name_evaluator_mapping.end();
}

void CurveEvaluators::cleanupCurveEvaluators(void)
{
	for (CurveNameEvaluatorMapping::iterator map_iterator = m_curve_name_evaluator_mapping.begin(); map_iterator != m_curve_name_evaluator_mapping.end(); ++map_iterator)
	{
		delete map_iterator->second;
	}
}


